@@ -5,18 +5,32 @@
 #'
 #' This function gives you access to hundreds of millions data series from
 #' \href{https://api.db.nomics.world/}{DBnomics API} (documentation about
-#' the API can be found \href{https://api.db.nomics.world/apidocs}{here}).
+#' the API can be found \href{https://api.db.nomics.world/v22/apidocs}{here}).
 #' The API link is given on the
 #' \href{https://db.nomics.world/}{DBnomics website}.
 #'
 #' @param api_link Character string. DBnomics API link of the search.
 #' @param use_readLines Logical (default \code{FALSE}). If \code{TRUE}, then
-#' the data are requested and read with the base function \code{readLines}.
-#' This can be used to get round the error \code{Could not resolve host: api.db.nomics.world}.
+#' the data are requested and read with the base function \code{readLines} i.e.
+#' through the default R internet connection. This can be used to get round the
+#' error \code{Could not resolve host: api.db.nomics.world}.
+#' @param curl_config Curl_handle or list (default \code{NULL}). If not
+#' \code{NULL}, it is used to configure a proxy connection. This
+#' configuration is passed to the function \code{curl_fetch_memory} of the package
+#' \pkg{curl}. If it is a \code{curl_handle} object then it is considered to
+#' be the argument \code{handle} of \code{curl_fetch_memory}. In the case of a
+#' list, the names of the object are the arguments names of
+#' \code{curl_fetch_memory} (except \code{url} of course). It means that
+#' \code{curl_config = h} is equivalent to
+#' \code{curl_config = list(handle = h)}. \cr
+#' For \code{curl_fetch_memory} arguments see \code{\link[curl]{curl_fetch}}.
+#' For available curl options see \code{\link[curl]{curl_options}},
+#' \code{names(curl_options())} and
+#' \href{https://curl.haxx.se/libcurl/c/curl_easy_setopt.html}{libcurl}.
 #' @return A \code{data.frame} or a \code{data.table}.
 #' @examples
 #' \dontrun{
-#' # Fetch two series from different datasets of different providers:
+#' # Fetch two series from different datasets of different providers :
 #' df1 <- rdb_by_api_link(
 #'   paste0(
 #'     'https://api.db.nomics.world/v22/',
@@ -24,7 +38,7 @@
 #'   )
 #' )
 #' 
-#' # Fetch one series from the dataset 'Doing Business' of WB provider:
+#' # Fetch one series from the dataset 'Doing Business' of WB provider :
 #' df2 <- rdb_by_api_link(
 #'   paste0(
 #'     'https://api.db.nomics.world/v22/series/WB/DB?dimensions=%7B%22',
@@ -33,8 +47,36 @@
 #'   )
 #' )
 #' 
-#' # Use readLines before fromJSON to avoid a proxy failure
-#' # Fetch one series from dataset 'Unemployment rate' (ZUTN) of AMECO provider:
+#' 
+#' ## Use a specific proxy to fetch the data
+#' # Fetch one series from the dataset 'Doing Business' of WB provider :
+#' h <- curl::new_handle(
+#'   proxy = "<proxy>",
+#'   proxyport = <port>,
+#'   proxyusername = "<username>",
+#'   proxypassword = "<password>"
+#' )
+#' options(rdbnomics.curl_config = h)
+#' df2 <- rdb_by_api_link(
+#'   paste0(
+#'     'https://api.db.nomics.world/v22/series/WB/DB?dimensions=%7B%22',
+#'     'indicator%22%3A%5B%22IC.REG.PROC.FE.NO%22%5D%7D&q=Doing%20Business',
+#'     '&observations=1&format=json&align_periods=1&offset=0&facets=0'
+#'   )
+#' )
+#' # or to use once
+#' df2 <- rdb_by_api_link(
+#'   paste0(
+#'     'https://api.db.nomics.world/v22/series/WB/DB?dimensions=%7B%22',
+#'     'indicator%22%3A%5B%22IC.REG.PROC.FE.NO%22%5D%7D&q=Doing%20Business',
+#'     '&observations=1&format=json&align_periods=1&offset=0&facets=0'
+#'   ),
+#'   curl_config = h
+#' )
+#'
+#' 
+#' ## Use R default connection to avoid a proxy failure (in some cases)
+#' # Fetch one series from the dataset 'Doing Business' of WB provider :
 #' options(rdbnomics.use_readLines = TRUE)
 #' df2 <- rdb_by_api_link(
 #'   paste0(
@@ -43,7 +85,7 @@
 #'     '&observations=1&format=json&align_periods=1&offset=0&facets=0'
 #'   )
 #' )
-#' # or
+#' # or to use once
 #' df2 <- rdb_by_api_link(
 #'   paste0(
 #'     'https://api.db.nomics.world/v22/series/WB/DB?dimensions=%7B%22',
@@ -56,7 +98,8 @@
 #' @seealso \code{\link{rdb}}
 #' @export
 rdb_by_api_link <- function(
-  api_link, use_readLines = getOption("rdbnomics.use_readLines")
+  api_link, use_readLines = getOption("rdbnomics.use_readLines"),
+  curl_config = getOption("rdbnomics.curl_config")
 ) {
   # Checking 'api_link'
   if (is.null(api_link)) { return(NULL) }
@@ -66,7 +109,7 @@ rdb_by_api_link <- function(
   check_argument(use_readLines, "logical")
 
   # Fetching data
-  DBlist <- read_lines(use_readLines, api_link)
+  DBlist <- get_data(api_link, use_readLines, curl_config)
 
   # Getting API version
   api_version <- get_version(DBlist)
@@ -76,7 +119,10 @@ rdb_by_api_link <- function(
   } else if (api_version == 22) {
     data_elt <- "docs"
   } else {
-    stop(paste0("Don't know what to do for API version ", api_version, "."))
+    stop(
+      paste0("Don't know what to do for API version ", api_version, "."),
+      call. = FALSE
+    )
   }
 
   # If data is empty, return NULL
@@ -116,7 +162,7 @@ rdb_by_api_link <- function(
       # Modifying link
       tmp_api_link <- paste0(api_link, sep, "offset=", i * limit)
       # Fetching data
-      DBlist <- read_lines(use_readLines, tmp_api_link)
+      DBlist <- get_data(tmp_api_link, use_readLines, curl_config)
       # Extracting data
       DBlist$series[[data_elt]]
     })
@@ -140,8 +186,29 @@ rdb_by_api_link <- function(
   transform_date_timestamp(DBdata)
 
   # Modifying column names
-  data.table::setnames(DBdata, "period", "original_period")
-  data.table::setnames(DBdata, "period_start_day", "period")
+  tryCatch({
+    data.table::setnames(DBdata, "period", "original_period")
+  }, error = function(e) {
+    stop(
+      paste0(
+        "The retrieved dataset doesn't have a column named 'period', it's not ",
+        "normal please check <db.nomics.world>."
+      ),
+      call. = FALSE
+    )
+  })
+
+  tryCatch({
+    data.table::setnames(DBdata, "period_start_day", "period")
+  }, error = function(e) {
+    stop(
+      paste0(
+        "The retrieved dataset doesn't have a column named ",
+        "'period_start_day', it's not normal please check <db.nomics.world>."
+      ),
+      call. = FALSE
+    )
+  })
 
   DBdata[]
 }
